@@ -32,22 +32,21 @@
 
 """|UDM| module for all |DNS| objects"""
 
+from typing import TYPE_CHECKING
+
 import six
 
 import univention.admin.filter
 import univention.admin.handlers
-import univention.admin.handlers.dns.alias
-import univention.admin.handlers.dns.forward_zone
-import univention.admin.handlers.dns.host_record
-import univention.admin.handlers.dns.ns_record
-import univention.admin.handlers.dns.ptr_record
-import univention.admin.handlers.dns.reverse_zone
-import univention.admin.handlers.dns.srv_record
-import univention.admin.handlers.dns.txt_record
 import univention.admin.localization
 from univention.admin.layout import Tab
 
 
+if TYPE_CHECKING:
+    import univention.admin
+    import univention.admin.uldap
+
+
 translation = univention.admin.localization.translation('univention.admin.handlers.dns')
 _ = translation.translate
 
@@ -62,7 +61,7 @@ long_description = _('Manage the Domain Name System.')
 operations = ['search']
 childmodules = ['dns/forward_zone', 'dns/reverse_zone']
 virtual = True
-options = {}
+options = {}  # type: dict[str, univention.admin.option]
 property_descriptions = {
     'name': univention.admin.property(
         short_description=_('Name'),
@@ -82,6 +81,7 @@ class object(univention.admin.handlers.simpleLdap):
 
 
 def rewrite(filter_s, **args):
+    # type: (str, str) -> str
     if not filter_s:
         return filter_s
     filter_p = univention.admin.filter.parse(filter_s)
@@ -92,26 +92,29 @@ def rewrite(filter_s, **args):
     return six.text_type(filter_p)
 
 
-def lookup(co, lo, filter_s, base='', superordinate=None, scope='sub', unique=False, required=False, timeout=-1, sizelimit=0):
-    ptr_filter = rewrite(filter_s, name='address')
-    fw_zone_filter = rewrite(filter_s, name='zone')
-    rv_zone_filter = rewrite(filter_s, name='subnet')
-    ret = []
-    if superordinate:
-        if superordinate.module == "dns/forward_zone":
-            ret += univention.admin.handlers.dns.host_record.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
-            ret += univention.admin.handlers.dns.alias.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
-            ret += univention.admin.handlers.dns.srv_record.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
-            ret += univention.admin.handlers.dns.txt_record.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
-            ret += univention.admin.handlers.dns.ns_record.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
-        else:
-            ret += univention.admin.handlers.dns.ptr_record.lookup(co, lo, ptr_filter, base, superordinate, scope, unique, required, timeout, sizelimit)
-    else:
-        ret += univention.admin.handlers.dns.forward_zone.lookup(co, lo, fw_zone_filter, base, superordinate, scope, unique, required, timeout, sizelimit)
-        ret += univention.admin.handlers.dns.reverse_zone.lookup(co, lo, rv_zone_filter, base, superordinate, scope, unique, required, timeout, sizelimit)
+MAP_SEARCH = {
+    "dns/forward_zone": "zone",
+    "dns/reverse_zone": "subnet",
+    "dns/ptr_record.py": "address",
+}
 
-    return ret
+
+def lookup(co, lo, filter_s, base='', superordinate=None, scope='sub', unique=False, required=False, timeout=-1, sizelimit=0):
+    # type: (None, univention.admin.uldap.access, str, str, univention.admin.handlers.simpleLdap | None, str, bool, bool, int, int) -> list[univention.admin.handlers.simpleLdap]
+    sup = univention.admin.modules._get(superordinate.module) if superordinate else None
+    res = []  # type: list[univention.admin.handlers.simpleLdap]
+    for childmodule in (sup.childmodules if sup else childmodules):
+        mod = univention.admin.modules._get(childmodule)
+        try:
+            attr = MAP_SEARCH[childmodule]
+        except LookupError:
+            fltr = filter_s
+        else:
+            fltr = rewrite(filter_s, name=attr)
+        res += mod.lookup(co, lo, fltr, base, superordinate, scope, unique, required, timeout, sizelimit)
+    return res
 
 
 def identify(dn, attr, canonical=False):
+    # type: (str, univention.admin.handlers._Attributes, bool) -> None
     pass
